@@ -21,8 +21,6 @@ Common parameter types for validating request Body.
 import re
 import unicodedata
 
-import six
-
 from masakari.i18n import _
 
 
@@ -48,7 +46,7 @@ def _is_printable(char):
 
 def _get_all_chars():
     for i in range(0xFFFF):
-        yield six.unichr(i)
+        yield chr(i)
 
 
 # build a regex that matches all printable characters. This allows
@@ -118,7 +116,7 @@ def _build_regex_range(ws=True, invert=False, exclude=None):
     return regex
 
 
-valid_description_regex_base = '^[\n%s]*$'
+valid_description_regex_base = '^[%s]*$'
 
 valid_name_regex_base = '^(?![%s])[%s]*(?<![%s])$'
 
