@@ -25,7 +25,6 @@ from oslo_context import context
 from oslo_db.sqlalchemy import enginefacade
 from oslo_log import log as logging
 from oslo_utils import timeutils
-import six
 
 from masakari import exception
 from masakari.i18n import _
@@ -121,7 +120,7 @@ class RequestContext(context.RequestContext):
         self.remote_address = remote_address
         if not timestamp:
             timestamp = timeutils.utcnow()
-        if isinstance(timestamp, six.string_types):
+        if isinstance(timestamp, str):
             timestamp = timeutils.parse_strtime(timestamp)
         self.timestamp = timestamp
 
