@@ -73,9 +73,11 @@ class PrepareHAEnabledInstancesTask(base.MasakariTask):
             ha_enabled_instances = []
             non_ha_enabled_instances = []
 
+            ha_enabled_key = CONF.host_failure.ha_enabled_instance_metadata_key
+
             for instance in instance_list:
                 is_instance_ha_enabled = strutils.bool_from_string(
-                    instance.metadata.get('HA_Enabled', False))
+                    instance.metadata.get(ha_enabled_key, False))
                 if CONF.host_failure.ignore_instances_in_error_state and (
                         getattr(instance, "OS-EXT-STS:vm_state") == "error"):
                     if is_instance_ha_enabled:
@@ -176,10 +178,11 @@ class EvacuateInstancesTask(base.MasakariTask):
                 periodic_call_stopped.wait)
         except etimeout.Timeout:
             with excutils.save_and_reraise_exception():
+                periodic_call_stopped.stop()
                 msg = ("Instance '%(uuid)s' is successfully evacuated but "
-                       "timeout to stop.") % {'uuid': instance.id}
+                       "failed to stop.") % {'uuid': instance.id}
                 LOG.warning(msg)
-        finally:
+        else:
             periodic_call_stopped.stop()
 
     def _evacuate_and_confirm(self, context, instance, host_name,
@@ -221,12 +224,13 @@ class EvacuateInstancesTask(base.MasakariTask):
                 etimeout.with_timeout(
                     CONF.wait_period_after_evacuation,
                     periodic_call.wait)
+            except exception.InstanceEvacuateFailed as e:
+                LOG.warning(str(e))
+                failed_evacuation_instances.append(instance.id)
             except etimeout.Timeout:
-                with excutils.save_and_reraise_exception():
-                    msg = ("Timeout for instance '%(uuid)s' evacuation."
-                           % {'uuid': instance.id})
-                    LOG.warning(msg)
-            finally:
+                # Instance is not evacuated in the expected time_limit.
+                failed_evacuation_instances.append(instance.id)
+            else:
                 # stop the periodic call, in case of exceptions or
                 # Timeout.
                 periodic_call.stop()
@@ -247,12 +251,6 @@ class EvacuateInstancesTask(base.MasakariTask):
                 if vm_state == 'resized' and power_state != SHUTDOWN:
                     stop_instance = False
 
-            elif vm_state == 'stopped' and task_state is None:
-                # If vm_state is stopped and task_state is none, the instance
-                # will be recovered with vm_state 'stopped'.
-                # So it doesn't need to stop the instance after evacuation.
-                stop_instance = False
-
             elif task_state is not None:
                 # Nova fails evacuation when the instance's task_state is not
                 # none. In this case, masakari resets the instance's vm_state
@@ -279,10 +277,9 @@ class EvacuateInstancesTask(base.MasakariTask):
         except etimeout.Timeout:
             # Instance is not stop in the expected time_limit.
             failed_evacuation_instances.append(instance.id)
-        except Exception as e:
+        except Exception:
             # Exception is raised while resetting instance state or
             # evacuating the instance itself.
-            LOG.warning(str(e))
             failed_evacuation_instances.append(instance.id)
         finally:
             if not instance_already_locked:
@@ -331,6 +328,13 @@ class EvacuateInstancesTask(base.MasakariTask):
                                 self.update_details(msg, 1.0)
                                 LOG.info(msg)
 
+                            # A failed compute host can be associated with
+                            # multiple aggregates but operators will not
+                            # associate it with multiple aggregates in real
+                            # deployment so adding reserved_host to the very
+                            # first aggregate from the list.
+                            break
+
                 self.novaclient.enable_disable_service(
                     context, reserved_host, enable=True)
 
