@@ -94,7 +94,7 @@ class MasakariManager(manager.Manager):
                 self.driver.execute_process_failure(
                     context, process_name, host_name,
                     notification.notification_uuid)
-            except exception.SkipProcessRecoveryException as e:
+            except exception.SkipProcessRecoveryException:
                 notification_status = fields.NotificationStatus.FINISHED
             except (exception.MasakariException,
                     exception.ProcessRecoveryFailureException) as e:
@@ -144,7 +144,7 @@ class MasakariManager(manager.Manager):
         except exception.IgnoreInstanceRecoveryException as e:
             notification_status = fields.NotificationStatus.IGNORED
             exception_info = e
-        except exception.SkipInstanceRecoveryException as e:
+        except exception.SkipInstanceRecoveryException:
             notification_status = fields.NotificationStatus.FINISHED
         except (exception.MasakariException,
                 exception.InstanceRecoveryFailureException) as e:
@@ -216,7 +216,7 @@ class MasakariManager(manager.Manager):
                     fields.FailoverSegmentRecoveryMethod.AUTO):
                 reserved_host_object_list = objects.HostList.get_all(
                     context, filters={
-                        'failover_segment_id': host_obj.failover_segment_id,
+                        'failover_segment_id': host_obj.failover_segment.uuid,
                         'reserved': True,
                         'on_maintenance': False
                         })
@@ -230,7 +230,7 @@ class MasakariManager(manager.Manager):
                     notification.notification_uuid,
                     update_host_method=update_host_method,
                     reserved_host_list=reserved_host_list)
-            except exception.SkipHostRecoveryException as e:
+            except exception.SkipHostRecoveryException:
                 notification_status = fields.NotificationStatus.FINISHED
             except (exception.HostRecoveryFailureException,
                     exception.ReservedHostsUnavailable,
@@ -368,6 +368,34 @@ class MasakariManager(manager.Manager):
                     {'notification_uuid': notification.notification_uuid,
                      'status': notification_status})
 
+    @periodic_task.periodic_task(
+        spacing=CONF.check_expired_notifications_interval)
+    def _check_expired_notifications(self, context):
+        filters = {
+            'status': [fields.NotificationStatus.RUNNING,
+                       fields.NotificationStatus.ERROR,
+                       fields.NotificationStatus.NEW]
+        }
+        notifications_list = objects.NotificationList.get_all(context,
+                                                              filters=filters)
+
+        for notification in notifications_list:
+            if timeutils.is_older_than(
+                    notification.generated_time,
+                    CONF.notifications_expired_interval):
+                # update running expired notification status as failed
+                notification_status = fields.NotificationStatus.FAILED
+                update_data = {
+                    'status': notification_status
+                }
+
+                notification.update(update_data)
+                notification.save()
+                LOG.error(
+                    "Periodic task 'check_expired_notifications': "
+                    "Notification %(notification_uuid)s is expired.",
+                    {'notification_uuid': notification.notification_uuid})
+
     def get_notification_recovery_workflow_details(self, context,
                                                    notification):
         """Retrieve recovery workflow details of the notification"""
