@@ -16,12 +16,12 @@
 """Tests for the notifications api."""
 
 import copy
+from http import client as http
 from unittest import mock
 
 import ddt
 from oslo_serialization import jsonutils
 from oslo_utils import timeutils
-from six.moves import http_client as http
 from webob import exc
 
 from masakari.api.openstack.ha import notifications
@@ -52,6 +52,7 @@ def _make_notifications_list(notifications_list):
     return notification_obj.Notification(objects=[
         _make_notification_obj(a) for a in notifications_list])
 
+
 NOTIFICATION_DATA = {"type": "VM", "id": 1,
                      "payload":
                          {'event': 'STOPPED', 'host_status': 'NORMAL',
@@ -494,7 +495,7 @@ class NotificationV1_1_TestCase(NotificationTestCase):
 
         result = self.controller.show(self.req, uuidsentinel.fake_notification)
         result = result['notification']
-        self.assertItemsEqual([RECOVERY_OBJ],
+        self.assertCountEqual([RECOVERY_OBJ],
                               result.recovery_workflow_details)
         self._assert_notification_data(NOTIFICATION_WITH_PROGRESS_DETAILS,
                                        _make_notification_obj(result))
