@@ -15,11 +15,11 @@
 
 """Tests for the failover segment api."""
 
+from http import client as http
 from unittest import mock
 
 import ddt
 from oslo_serialization import jsonutils
-from six.moves import http_client as http
 from webob import exc
 
 from masakari.api.openstack.ha import segments
@@ -40,6 +40,7 @@ def _make_segments_list(segments_list):
     return segment_obj.FailoverSegment(objects=[
         _make_segment_obj(a) for a in segments_list])
 
+
 FAILOVER_SEGMENT_LIST = [
     {"name": "segment1", "id": "1", "service_type": "COMPUTE",
      "recovery_method": "auto", "uuid": uuidsentinel.fake_segment,
