@@ -14,10 +14,10 @@
 #    under the License.
 
 import copy
+from http import client as http
 from unittest import mock
 
 from oslo_serialization import jsonutils
-from six.moves import http_client as http
 import webob
 
 from masakari.api import api_version_request as avr
@@ -213,49 +213,14 @@ class VersionsTest(test.NoDBTestCase):
     def wsgi_app(self):
         return fakes.wsgi_app_v1(init_only=('versions',))
 
-    def _test_v1(self, path):
-        req = webob.Request.blank(path)
+    @mock.patch('masakari.rpc.get_client')
+    def test_get_version_list_302(self, mock_get_client):
+        req = webob.Request.blank('/v1')
         req.accept = "application/json"
         res = req.get_response(self.wsgi_app)
-        self.assertEqual(200, res.status_int)
-        self.assertEqual("application/json", res.content_type)
-        version = jsonutils.loads(res.body)
-        expected = {
-            "version": {
-                "id": "v1.0",
-                "status": "CURRENT",
-                "version": "1.1",
-                "min_version": "1.0",
-                "updated": "2016-07-01T11:33:21Z",
-                "links": [
-                    {
-                        "rel": "self",
-                        "href": "http://localhost/v1/",
-                    },
-                    {
-                        "rel": "describedby",
-                        "type": "text/html",
-                        "href": "https://docs.openstack.org/",
-                    },
-                ],
-                "media-types": [
-                    {
-                        "base": "application/json",
-                        "type": "application/"
-                                "vnd.openstack.masakari+json;version=1",
-                    },
-                ],
-            },
-        }
-        self.assertEqual(expected, version)
-
-    @mock.patch('masakari.rpc.get_client')
-    def test_get_version_1_detail(self, mock_get_client):
-        self._test_v1('/v1/')
-
-    @mock.patch('masakari.rpc.get_client')
-    def test_get_version_1_detail_no_slash(self, mock_get_client):
-        self._test_v1('/v1')
+        self.assertEqual(http.FOUND, res.status_int)
+        redirect_req = webob.Request.blank('/v1/')
+        self.assertEqual(redirect_req.url, res.location)
 
     @mock.patch('masakari.rpc.get_client')
     def test_get_version_1_versions_invalid(self, mock_get_client):
