@@ -12,10 +12,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from http import client as http
 from unittest import mock
 
-from six.moves import http_client as http
-
 from keystoneauth1 import exceptions as keystone_exception
 from novaclient import exceptions as nova_exception
 
@@ -305,26 +304,29 @@ class NovaApiTestCase(test.TestCase):
         mock_servers.unlock.assert_called_once_with(uuidsentinel.fake_server)
 
     @mock.patch('masakari.compute.nova.novaclient')
-    def test_hypervisor_search_non_existing_host_name(self, mock_novaclient):
-        mock_novaclient.return_value.hypervisors.search.side_effect = (
-            nova_exception.NotFound(http.NOT_FOUND))
+    def test_find_compute_service_non_existing_host_name(
+            self, mock_novaclient):
+        host = 'fake'
 
-        self.assertRaises(exception.HypervisorNotFoundByName,
-                          self.api.hypervisor_search, context, 'abc')
+        mock_services = mock.MagicMock()
+        mock_novaclient.return_value = mock.MagicMock(services=mock_services)
+        mock_services.list.return_value = []
+
+        self.assertRaises(exception.ComputeNotFoundByName,
+            self.api.find_compute_service, self.ctx, host)
+        mock_novaclient.assert_called_once_with(self.ctx)
+        mock_services.list.assert_called_once_with(host=host,
+                                                   binary='nova-compute')
 
     @mock.patch('masakari.compute.nova.novaclient')
-    def test_hypervisor_search_case_sensitive(self, mock_novaclient):
-        test_hypers = [
-            dict(id=1,
-                 uuid=uuidsentinel.hyper1,
-                 hypervisor_hostname="xyz.one"),
-            dict(id=2,
-                 uuid=uuidsentinel.hyper2,
-                 hypervisor_hostname="xyz.two", ),
-            dict(id=3,
-                 uuid=uuidsentinel.hyper3,
-                 hypervisor_hostname="XYZ", )
-        ]
-        mock_novaclient.hypervisors.search.return_value = test_hypers
-        self.assertRaises(exception.HypervisorNotFoundByName,
-                          self.api.hypervisor_search, context, 'xyz')
+    def test_find_compute_service_existing_host_name(self, mock_novaclient):
+        host = 'fake'
+
+        mock_services = mock.MagicMock()
+        mock_novaclient.return_value = mock.MagicMock(services=mock_services)
+        mock_services.list.return_value = [mock.MagicMock(id='fake_id')]
+
+        self.assertIsNone(self.api.find_compute_service(self.ctx, host))
+        mock_novaclient.assert_called_once_with(self.ctx)
+        mock_services.list.assert_called_once_with(binary='nova-compute',
+                                                   host=host)
