@@ -13,13 +13,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from http import client as http
 import re
 
 import fixtures
 from jsonschema import exceptions as jsonschema_exc
-import six
-from six.moves import http_client as http
-import sys
 
 from masakari.api import api_version_request as api_version
 from masakari.api import validation
@@ -40,7 +38,7 @@ class ValidationRegex(test.NoDBTestCase):
 
         def _get_all_chars():
             for i in range(0x7F):
-                yield six.unichr(i)
+                yield chr(i)
 
         self.useFixture(fixtures.MonkeyPatch(
             'masakari.api.validation.parameter_types._get_all_chars',
@@ -270,10 +268,7 @@ class PatternPropertiesTestCase(APIValidationTestCase):
         self.check_validation_error(self.post, body={'0123456789a': 'bar'},
                                     expected_detail=details)
 
-        if sys.version[:3] == '3.5':
-            detail = "expected string or bytes-like object"
-        else:
-            detail = "expected string or buffer"
+        detail = "expected string or bytes-like object"
         self.check_validation_error(self.post, body={None: 'bar'},
                                     expected_detail=detail)
 
